@@ -28,6 +28,9 @@ from .library import Library
 
 
 JINJA2_ENVIRONMENT_OPTIONS = getattr(settings, 'JINJA2_ENVIRONMENT_OPTIONS', {})
+JINJA2_LOADER = getattr(settings, 'JINJA2_LOADER',
+                        FileSystemLoader(app_directories.app_template_dirs + tuple(settings.TEMPLATE_DIRS)))
+JINJA2_LOADER_SETTINGS = getattr(settings, 'JINJA2_LOADER_SETTINGS', {})
 JINJA2_EXTENSIONS = getattr(settings, 'JINJA2_EXTENSIONS', [])
 JINJA2_FILTERS = getattr(settings, 'JINJA2_FILTERS', {})
 JINJA2_FILTERS_REPLACE_FROM_DJANGO = getattr(settings, 'JINJA2_FILTERS_REPLACE_FROM_DJANGO', True)
@@ -169,6 +172,13 @@ class Environment(Environment):
             cls = utils.load_class(JINJA2_BYTECODE_CACHE_BACKEND)
             self.bytecode_cache = cls(JINJA2_BYTECODE_CACHE_NAME)
 
+        # Setup template loader
+        if isinstance(JINJA2_LOADER, six.string_types):
+            cls = utils.load_class(JINJA2_LOADER)
+            self.loader = cls(**JINJA2_LOADER_SETTINGS)
+        else:
+            self.loader = JINJA2_LOADER
+
         # Add filters defined on settings + builtins
         for name, value in JINJA2_FILTERS.items():
             if isinstance(value, six.string_types):
@@ -202,8 +212,8 @@ class Environment(Environment):
             if not os.path.isdir(mod_path):
                 continue
 
-            for filename in filter(lambda x: x.endswith(".py"), os.listdir(mod_path)):
-                if filename == '__init__.py':
+            for filename in filter(lambda x: x.endswith(".py") or x.endswith(".pyc"), os.listdir(mod_path)):
+                if filename == '__init__.py' or filename == '__init__.pyc':
                     continue
 
                 file_mod_path = "%s.templatetags.%s" % (app_path, filename.rsplit(".", 1)[0])
@@ -241,8 +251,6 @@ class Environment(Environment):
 
 initial_params = {
     'autoescape': JINJA2_AUTOESCAPE,
-    'loader': FileSystemLoader(tuple(settings.TEMPLATE_DIRS) +
-                               app_directories.app_template_dirs),
     'extensions': list(set(list(JINJA2_EXTENSIONS) + DEFAULT_EXTENSIONS)),
 }
 
